Buffer

Struct Buffer 

pub struct Buffer { /* private fields */ }
A buffer returned by a camera to accommodate custom decoding. Contains information of Resolution, the buffer’s FrameFormat, and the buffer.

Note that decoding on the main thread will decrease your performance and lead to dropped frames.

Implementations

Source

impl Buffer

pub fn new( res: Resolution, buf: &[u8], source_frame_format: FrameFormat, ) -> Self

Creates a new buffer with a [&[u8]].

pub fn with_timestamp( res: Resolution, buf: &[u8], source_frame_format: FrameFormat, capture_timestamp: Option<Duration>, ) -> Self

Creates a new buffer with a [&[u8]] and a backend-provided capture timestamp.

pub fn capture_timestamp(&self) -> Option<Duration>

Get the backend-provided capture timestamp, if available.

pub fn resolution(&self) -> Resolution

Get the Resolution of this buffer.

pub fn buffer(&self) -> &[u8]

Get the data of this buffer.

pub fn buffer_bytes(&self) -> Bytes

Get a owned version of this buffer.

pub fn source_frame_format(&self) -> FrameFormat

Get the FrameFormat of this buffer.

pub fn decode_image<F: FormatDecoder>( &self, ) -> Result<ImageBuffer<F::Output, Vec<u8>>, NokhwaError>

Decodes a image with allocation using the provided FormatDecoder.

Errors

Will error when the decoding fails.

pub fn decode_image_to_buffer<F: FormatDecoder>( &self, buffer: &mut [u8], ) -> Result<(), NokhwaError>

Decodes a image with allocation using the provided FormatDecoder into a buffer.

Errors

Will error when the decoding fails, or the provided buffer is too small.